==> zio-aws-kinesisvideoarchivedmedia_3-5.17.129.2-sources.jar: zio/aws/kinesisvideoarchivedmedia/model/HLSTimestampRange.scala <==
package zio.aws.kinesisvideoarchivedmedia.model
import zio.aws.kinesisvideoarchivedmedia.model.primitives.Timestamp
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class HLSTimestampRange(
    startTimestamp: Option[Timestamp] = None,
    endTimestamp: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange = {
    import HLSTimestampRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange
      .builder()
      .optionallyWith(
        startTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.startTimestamp)
      .optionallyWith(
        endTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.endTimestamp)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange.ReadOnly =
    zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange
      .wrap(buildAwsValue())
}
object HLSTimestampRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange =
      zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange(
        startTimestamp.map(value => value),
        endTimestamp.map(value => value)
      )
    def startTimestamp: Option[Timestamp]
    def endTimestamp: Option[Timestamp]
    def getStartTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("startTimestamp", startTimestamp)
    def getEndTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("endTimestamp", endTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange
  ) extends zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange.ReadOnly {
    override val startTimestamp: Option[Timestamp] = scala
      .Option(impl.startTimestamp())
      .map(value =>
        zio.aws.kinesisvideoarchivedmedia.model.primitives.Timestamp(value)
      )
    override val endTimestamp: Option[Timestamp] = scala
      .Option(impl.endTimestamp())
      .map(value =>
        zio.aws.kinesisvideoarchivedmedia.model.primitives.Timestamp(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange
  ): zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisvideoarchivedmedia_3-5.17.295.4-sources.jar: zio/aws/kinesisvideoarchivedmedia/model/HLSTimestampRange.scala <==
package zio.aws.kinesisvideoarchivedmedia.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.kinesisvideoarchivedmedia.model.primitives.Timestamp
import scala.jdk.CollectionConverters.*
final case class HLSTimestampRange(
    startTimestamp: Optional[Timestamp] = Optional.Absent,
    endTimestamp: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange = {
    import HLSTimestampRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange
      .builder()
      .optionallyWith(
        startTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.startTimestamp)
      .optionallyWith(
        endTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.endTimestamp)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange.ReadOnly =
    zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange
      .wrap(buildAwsValue())
}
object HLSTimestampRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange =
      zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange(
        startTimestamp.map(value => value),
        endTimestamp.map(value => value)
      )
    def startTimestamp: Optional[Timestamp]
    def endTimestamp: Optional[Timestamp]
    def getStartTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("startTimestamp", startTimestamp)
    def getEndTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("endTimestamp", endTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange
  ) extends zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange.ReadOnly {
    override val startTimestamp: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.startTimestamp())
      .map(value =>
        zio.aws.kinesisvideoarchivedmedia.model.primitives.Timestamp(value)
      )
    override val endTimestamp: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.endTimestamp())
      .map(value =>
        zio.aws.kinesisvideoarchivedmedia.model.primitives.Timestamp(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisvideoarchivedmedia.model.HLSTimestampRange
  ): zio.aws.kinesisvideoarchivedmedia.model.HLSTimestampRange.ReadOnly =
    new Wrapper(impl)
}
